@@ -1,7 +1,7 @@
 package Media::Info::Ffmpeg;
 
 our $DATE = '2019-01-28'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -63,7 +63,7 @@ sub get_media_info {
     if ($stderr =~ /^\s*Stream.+?: Video: (.+)/m) {
         my $video_info = $1;
         $video_info =~ /^(\w+)/; $info->{video_format} = uc($1);
-        $video_info =~ /(\d+)x(\d+),/ and do {
+        $video_info =~ /([1-9]\d*)x(\d+)/ and do {
             $info->{video_width}  = $1;
             $info->{video_height} = $2;
         };
@@ -97,7 +97,7 @@ Media::Info::Ffmpeg - Return information on media file/URL, using ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.006 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2019-01-28.
+This document describes version 0.007 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2019-01-28.
 
 =head1 SYNOPSIS
 
